==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/extraction/info/InformationType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for InformationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="InformationType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="description" type="{http://schema.webpdf.de/1.0/extraction/info}DescriptionType"/&gt;
 *         &lt;element name="pdfa" type="{http://schema.webpdf.de/1.0/extraction/info}PdfaType"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="version" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="fileSize" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}long"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="pageLayout" type="{http://schema.webpdf.de/1.0/extraction/info}PageLayoutType" default="singlePage" /&gt;
 *       &lt;attribute name="encrypted" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="portfolio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="pages"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="attachments" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="formType" type="{http://schema.webpdf.de/1.0/extraction/info}FormsFormatType" default="none" /&gt;
 *       &lt;attribute name="signatures" type="{http://www.w3.org/2001/XMLSchema}int" default="0" /&gt;
 *       &lt;attribute name="docMDP" type="{http://schema.webpdf.de/1.0/extraction/info}DocMdpType" default="none" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "InformationType", propOrder = {
    "description",
    "pdfa"
})
public class InformationType {

    @XmlElement(required = true)
    protected DescriptionType description;
    @XmlElement(required = true)
    protected PdfaType pdfa;
    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "fileSize")
    protected Long fileSize;
    @XmlAttribute(name = "pageLayout")
    protected PageLayoutType pageLayout;
    @XmlAttribute(name = "encrypted")
    protected Boolean encrypted;
    @XmlAttribute(name = "portfolio")
    protected Boolean portfolio;
    @XmlAttribute(name = "pages")
    protected Integer pages;
    @XmlAttribute(name = "attachments")
    protected Integer attachments;
    @XmlAttribute(name = "formType")
    protected FormsFormatType formType;
    @XmlAttribute(name = "signatures")
    protected Integer signatures;
    @XmlAttribute(name = "docMDP")
    protected DocMdpType docMDP;

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link DescriptionType }
     *     
     */
    public DescriptionType getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link DescriptionType }
     *     
     */
    public void setDescription(DescriptionType value) {
        this.description = value;
    }

    public boolean isSetDescription() {
        return (this.description!= null);
    }

    /**
     * Gets the value of the pdfa property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType }
     *     
     */
    public PdfaType getPdfa() {
        return pdfa;
    }

    /**
     * Sets the value of the pdfa property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType }
     *     
     */
    public void setPdfa(PdfaType value) {
        this.pdfa = value;
    }

    public boolean isSetPdfa() {
        return (this.pdfa!= null);
    }

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    public boolean isSetVersion() {
        return (this.version!= null);
    }

    /**
     * Gets the value of the fileSize property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getFileSize() {
        if (fileSize == null) {
            return  0L;
        } else {
            return fileSize;
        }
    }

    /**
     * Sets the value of the fileSize property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setFileSize(long value) {
        this.fileSize = value;
    }

    public boolean isSetFileSize() {
        return (this.fileSize!= null);
    }

    public void unsetFileSize() {
        this.fileSize = null;
    }

    /**
     * Gets the value of the pageLayout property.
     * 
     * @return
     *     possible object is
     *     {@link PageLayoutType }
     *     
     */
    public PageLayoutType getPageLayout() {
        if (pageLayout == null) {
            return PageLayoutType.SINGLE_PAGE;
        } else {
            return pageLayout;
        }
    }

    /**
     * Sets the value of the pageLayout property.
     * 
     * @param value
     *     allowed object is
     *     {@link PageLayoutType }
     *     
     */
    public void setPageLayout(PageLayoutType value) {
        this.pageLayout = value;
    }

    public boolean isSetPageLayout() {
        return (this.pageLayout!= null);
    }

    /**
     * Gets the value of the encrypted property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isEncrypted() {
        if (encrypted == null) {
            return false;
        } else {
            return encrypted;
        }
    }

    /**
     * Sets the value of the encrypted property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEncrypted(boolean value) {
        this.encrypted = value;
    }

    public boolean isSetEncrypted() {
        return (this.encrypted!= null);
    }

    public void unsetEncrypted() {
        this.encrypted = null;
    }

    /**
     * Gets the value of the portfolio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPortfolio() {
        if (portfolio == null) {
            return false;
        } else {
            return portfolio;
        }
    }

    /**
     * Sets the value of the portfolio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPortfolio(boolean value) {
        this.portfolio = value;
    }

    public boolean isSetPortfolio() {
        return (this.portfolio!= null);
    }

    public void unsetPortfolio() {
        this.portfolio = null;
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPages(int value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    public void unsetPages() {
        this.pages = null;
    }

    /**
     * Gets the value of the attachments property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getAttachments() {
        if (attachments == null) {
            return  0;
        } else {
            return attachments;
        }
    }

    /**
     * Sets the value of the attachments property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAttachments(int value) {
        this.attachments = value;
    }

    public boolean isSetAttachments() {
        return (this.attachments!= null);
    }

    public void unsetAttachments() {
        this.attachments = null;
    }

    /**
     * Gets the value of the formType property.
     * 
     * @return
     *     possible object is
     *     {@link FormsFormatType }
     *     
     */
    public FormsFormatType getFormType() {
        if (formType == null) {
            return FormsFormatType.NONE;
        } else {
            return formType;
        }
    }

    /**
     * Sets the value of the formType property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsFormatType }
     *     
     */
    public void setFormType(FormsFormatType value) {
        this.formType = value;
    }

    public boolean isSetFormType() {
        return (this.formType!= null);
    }

    /**
     * Gets the value of the signatures property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSignatures() {
        if (signatures == null) {
            return  0;
        } else {
            return signatures;
        }
    }

    /**
     * Sets the value of the signatures property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSignatures(int value) {
        this.signatures = value;
    }

    public boolean isSetSignatures() {
        return (this.signatures!= null);
    }

    public void unsetSignatures() {
        this.signatures = null;
    }

    /**
     * Gets the value of the docMDP property.
     * 
     * @return
     *     possible object is
     *     {@link DocMdpType }
     *     
     */
    public DocMdpType getDocMDP() {
        if (docMDP == null) {
            return DocMdpType.NONE;
        } else {
            return docMDP;
        }
    }

    /**
     * Sets the value of the docMDP property.
     * 
     * @param value
     *     allowed object is
     *     {@link DocMdpType }
     *     
     */
    public void setDocMDP(DocMdpType value) {
        this.docMDP = value;
    }

    public boolean isSetDocMDP() {
        return (this.docMDP!= null);
    }

}

==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/info/InformationType.java <==

package net.webpdf.wsclient.schema.extraction.info;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for InformationType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="InformationType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="description" type="{http://schema.webpdf.de/1.0/extraction/info}DescriptionType"/&gt;
 *         &lt;element name="pdfa" type="{http://schema.webpdf.de/1.0/extraction/info}PdfaType"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute name="objectKey" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="version" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *       &lt;attribute name="fileSize" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}long"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="initialPage" type="{http://www.w3.org/2001/XMLSchema}int" default="1" /&gt;
 *       &lt;attribute name="pageLayout" type="{http://schema.webpdf.de/1.0/extraction/info}PageLayoutType" default="singlePage" /&gt;
 *       &lt;attribute name="magnification" type="{http://schema.webpdf.de/1.0/extraction/info}MagnificationType" default="fitVisible" /&gt;
 *       &lt;attribute name="magnificationZoom" default="100"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="initialView" type="{http://schema.webpdf.de/1.0/extraction/info}InitialViewType" default="none" /&gt;
 *       &lt;attribute name="encrypted" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="portfolio" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="pages"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="attachments" default="0"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="formType" type="{http://schema.webpdf.de/1.0/extraction/info}FormsFormatType" default="none" /&gt;
 *       &lt;attribute name="signatures" type="{http://www.w3.org/2001/XMLSchema}int" default="0" /&gt;
 *       &lt;attribute name="docMDP" type="{http://schema.webpdf.de/1.0/extraction/info}DocMdpType" default="none" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "InformationType", propOrder = {
    "description",
    "pdfa"
})
public class InformationType {

    @XmlElement(required = true)
    protected DescriptionType description;
    @XmlElement(required = true)
    protected PdfaType pdfa;
    @XmlAttribute(name = "objectKey")
    protected String objectKey;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "fileSize")
    protected Long fileSize;
    @XmlAttribute(name = "initialPage")
    protected Integer initialPage;
    @XmlAttribute(name = "pageLayout")
    protected PageLayoutType pageLayout;
    @XmlAttribute(name = "magnification")
    protected MagnificationType magnification;
    @XmlAttribute(name = "magnificationZoom")
    protected Integer magnificationZoom;
    @XmlAttribute(name = "initialView")
    protected InitialViewType initialView;
    @XmlAttribute(name = "encrypted")
    protected Boolean encrypted;
    @XmlAttribute(name = "portfolio")
    protected Boolean portfolio;
    @XmlAttribute(name = "pages")
    protected Integer pages;
    @XmlAttribute(name = "attachments")
    protected Integer attachments;
    @XmlAttribute(name = "formType")
    protected FormsFormatType formType;
    @XmlAttribute(name = "signatures")
    protected Integer signatures;
    @XmlAttribute(name = "docMDP")
    protected DocMdpType docMDP;

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link DescriptionType }
     *     
     */
    public DescriptionType getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link DescriptionType }
     *     
     */
    public void setDescription(DescriptionType value) {
        this.description = value;
    }

    public boolean isSetDescription() {
        return (this.description!= null);
    }

    /**
     * Gets the value of the pdfa property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType }
     *     
     */
    public PdfaType getPdfa() {
        return pdfa;
    }

    /**
     * Sets the value of the pdfa property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType }
     *     
     */
    public void setPdfa(PdfaType value) {
        this.pdfa = value;
    }

    public boolean isSetPdfa() {
        return (this.pdfa!= null);
    }

    /**
     * Gets the value of the objectKey property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getObjectKey() {
        if (objectKey == null) {
            return "";
        } else {
            return objectKey;
        }
    }

    /**
     * Sets the value of the objectKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setObjectKey(String value) {
        this.objectKey = value;
    }

    public boolean isSetObjectKey() {
        return (this.objectKey!= null);
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    public boolean isSetVersion() {
        return (this.version!= null);
    }

    /**
     * Gets the value of the fileSize property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getFileSize() {
        if (fileSize == null) {
            return  0L;
        } else {
            return fileSize;
        }
    }

    /**
     * Sets the value of the fileSize property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setFileSize(long value) {
        this.fileSize = value;
    }

    public boolean isSetFileSize() {
        return (this.fileSize!= null);
    }

    public void unsetFileSize() {
        this.fileSize = null;
    }

    /**
     * Gets the value of the initialPage property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getInitialPage() {
        if (initialPage == null) {
            return  1;
        } else {
            return initialPage;
        }
    }

    /**
     * Sets the value of the initialPage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setInitialPage(int value) {
        this.initialPage = value;
    }

    public boolean isSetInitialPage() {
        return (this.initialPage!= null);
    }

    public void unsetInitialPage() {
        this.initialPage = null;
    }

    /**
     * Gets the value of the pageLayout property.
     * 
     * @return
     *     possible object is
     *     {@link PageLayoutType }
     *     
     */
    public PageLayoutType getPageLayout() {
        if (pageLayout == null) {
            return PageLayoutType.SINGLE_PAGE;
        } else {
            return pageLayout;
        }
    }

    /**
     * Sets the value of the pageLayout property.
     * 
     * @param value
     *     allowed object is
     *     {@link PageLayoutType }
     *     
     */
    public void setPageLayout(PageLayoutType value) {
        this.pageLayout = value;
    }

    public boolean isSetPageLayout() {
        return (this.pageLayout!= null);
    }

    /**
     * Gets the value of the magnification property.
     * 
     * @return
     *     possible object is
     *     {@link MagnificationType }
     *     
     */
    public MagnificationType getMagnification() {
        if (magnification == null) {
            return MagnificationType.FIT_VISIBLE;
        } else {
            return magnification;
        }
    }

    /**
     * Sets the value of the magnification property.
     * 
     * @param value
     *     allowed object is
     *     {@link MagnificationType }
     *     
     */
    public void setMagnification(MagnificationType value) {
        this.magnification = value;
    }

    public boolean isSetMagnification() {
        return (this.magnification!= null);
    }

    /**
     * Gets the value of the magnificationZoom property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getMagnificationZoom() {
        if (magnificationZoom == null) {
            return  100;
        } else {
            return magnificationZoom;
        }
    }

    /**
     * Sets the value of the magnificationZoom property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setMagnificationZoom(int value) {
        this.magnificationZoom = value;
    }

    public boolean isSetMagnificationZoom() {
        return (this.magnificationZoom!= null);
    }

    public void unsetMagnificationZoom() {
        this.magnificationZoom = null;
    }

    /**
     * Gets the value of the initialView property.
     * 
     * @return
     *     possible object is
     *     {@link InitialViewType }
     *     
     */
    public InitialViewType getInitialView() {
        if (initialView == null) {
            return InitialViewType.NONE;
        } else {
            return initialView;
        }
    }

    /**
     * Sets the value of the initialView property.
     * 
     * @param value
     *     allowed object is
     *     {@link InitialViewType }
     *     
     */
    public void setInitialView(InitialViewType value) {
        this.initialView = value;
    }

    public boolean isSetInitialView() {
        return (this.initialView!= null);
    }

    /**
     * Gets the value of the encrypted property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isEncrypted() {
        if (encrypted == null) {
            return false;
        } else {
            return encrypted;
        }
    }

    /**
     * Sets the value of the encrypted property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setEncrypted(boolean value) {
        this.encrypted = value;
    }

    public boolean isSetEncrypted() {
        return (this.encrypted!= null);
    }

    public void unsetEncrypted() {
        this.encrypted = null;
    }

    /**
     * Gets the value of the portfolio property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isPortfolio() {
        if (portfolio == null) {
            return false;
        } else {
            return portfolio;
        }
    }

    /**
     * Sets the value of the portfolio property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setPortfolio(boolean value) {
        this.portfolio = value;
    }

    public boolean isSetPortfolio() {
        return (this.portfolio!= null);
    }

    public void unsetPortfolio() {
        this.portfolio = null;
    }

    /**
     * Gets the value of the pages property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPages() {
        return pages;
    }

    /**
     * Sets the value of the pages property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPages(int value) {
        this.pages = value;
    }

    public boolean isSetPages() {
        return (this.pages!= null);
    }

    public void unsetPages() {
        this.pages = null;
    }

    /**
     * Gets the value of the attachments property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getAttachments() {
        if (attachments == null) {
            return  0;
        } else {
            return attachments;
        }
    }

    /**
     * Sets the value of the attachments property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAttachments(int value) {
        this.attachments = value;
    }

    public boolean isSetAttachments() {
        return (this.attachments!= null);
    }

    public void unsetAttachments() {
        this.attachments = null;
    }

    /**
     * Gets the value of the formType property.
     * 
     * @return
     *     possible object is
     *     {@link FormsFormatType }
     *     
     */
    public FormsFormatType getFormType() {
        if (formType == null) {
            return FormsFormatType.NONE;
        } else {
            return formType;
        }
    }

    /**
     * Sets the value of the formType property.
     * 
     * @param value
     *     allowed object is
     *     {@link FormsFormatType }
     *     
     */
    public void setFormType(FormsFormatType value) {
        this.formType = value;
    }

    public boolean isSetFormType() {
        return (this.formType!= null);
    }

    /**
     * Gets the value of the signatures property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getSignatures() {
        if (signatures == null) {
            return  0;
        } else {
            return signatures;
        }
    }

    /**
     * Sets the value of the signatures property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setSignatures(int value) {
        this.signatures = value;
    }

    public boolean isSetSignatures() {
        return (this.signatures!= null);
    }

    public void unsetSignatures() {
        this.signatures = null;
    }

    /**
     * Gets the value of the docMDP property.
     * 
     * @return
     *     possible object is
     *     {@link DocMdpType }
     *     
     */
    public DocMdpType getDocMDP() {
        if (docMDP == null) {
            return DocMdpType.NONE;
        } else {
            return docMDP;
        }
    }

    /**
     * Sets the value of the docMDP property.
     * 
     * @param value
     *     allowed object is
     *     {@link DocMdpType }
     *     
     */
    public void setDocMDP(DocMdpType value) {
        this.docMDP = value;
    }

    public boolean isSetDocMDP() {
        return (this.docMDP!= null);
    }

}
